@@ -7,10 +7,10 @@ module Cucumber
     it 'outputs a message to $stderr' do
       allow($stderr).to receive(:puts)
 
-      Cucumber.deprecate('Use some_method instead', 'someMethod', '1.0.0')
+      Cucumber.deprecate('Use #some_other_method instead', '#some_method', '1.0.0')
       expect($stderr).to have_received(:puts).with(
         a_string_including(
-          'WARNING: #someMethod is deprecated and will be removed after version 1.0.0. Use some_method instead.'
+          'WARNING: #some_method is deprecated and will be removed after version 1.0.0. Use #some_other_method instead.'
         )
       )
     end
